@@ -1,7 +1,4 @@
 """Impressions model module."""
-from __future__ import absolute_import, division, print_function, \
-    unicode_literals
-
 from collections import namedtuple
 
 
