@@ -1,10 +1,5 @@
 """Redis client wrapper with prefix support."""
-from __future__ import absolute_import, division, print_function, \
-    unicode_literals
-
 from builtins import str
-from six import string_types, binary_type
-from future.utils import raise_from
 
 try:
     from redis import StrictRedis
@@ -20,12 +15,6 @@ except ImportError:
     StrictRedis = Sentinel = missing_redis_dependencies
 
 
-def _bytes_to_string(maybe_bytes, encode='utf-8'):
-    if type(maybe_bytes).__name__ == 'bytes':
-        return str(maybe_bytes, encode)
-    return maybe_bytes
-
-
 class RedisAdapterException(Exception):
     """Exception to be thrown when a redis command fails with an exception."""
 
@@ -68,25 +57,19 @@ class PrefixHelper(object):
         """
         Add a prefix to the contents of k.
 
-        'k' may be:
-            - a single key (of type string or unicode in python2, or type string
-            in python 3. In which case we simple add a prefix with a dot.
-            - a list, in which the prefix is applied to element.
-        If no user prefix is stored, the key/list of keys will be returned as is
-
-        :param k: single (string) or list of (list) keys.
+        :param k: single (string).
         :returns: Key(s) with prefix if applicable
         """
         if self._prefix:
-            if isinstance(k, string_types):
+            if isinstance(k, str):
                 return '{prefix}.{key}'.format(prefix=self._prefix, key=k)
             elif isinstance(k, list) and k:
-                if isinstance(k[0], binary_type):
+                if isinstance(k[0], bytes):
                     return [
                         '{prefix}.{key}'.format(prefix=self._prefix, key=key.decode("utf8"))
                         for key in k
                     ]
-                elif isinstance(k[0], string_types):
+                elif isinstance(k[0], str):
                     return [
                         '{prefix}.{key}'.format(prefix=self._prefix, key=key)
                         for key in k
@@ -109,7 +92,7 @@ class PrefixHelper(object):
         :returns: prefix-less key(s)
         """
         if self._prefix:
-            if isinstance(k, string_types):
+            if isinstance(k, str):
                 return k[len(self._prefix)+1:]
             elif isinstance(k, list):
                 return [key[len(self._prefix)+1:] for key in k]
@@ -146,11 +129,11 @@ class RedisAdapter(object):  # pylint: disable=too-many-public-methods
         """Mimic original redis function but using user custom prefix."""
         try:
             return [
-                _bytes_to_string(key)
+                key
                 for key in self._prefix_helper.remove_prefix(self._decorated.keys(self._prefix_helper.add_prefix(pattern)))
             ]
         except RedisError as exc:
-            raise_from(RedisAdapterException('Failed to execute keys operation'), exc)
+            raise RedisAdapterException('Failed to execute keys operation') from exc
 
     def set(self, name, value, *args, **kwargs):
         """Mimic original redis function but using user custom prefix."""
@@ -159,160 +142,160 @@ class RedisAdapter(object):  # pylint: disable=too-many-public-methods
                 self._prefix_helper.add_prefix(name), value, *args, **kwargs
             )
         except RedisError as exc:
-            raise_from(RedisAdapterException('Failed to execute set operation'), exc)
+            raise RedisAdapterException('Failed to execute set operation') from exc
 
     def get(self, name):
         """Mimic original redis function but using user custom prefix."""
         try:
-            return _bytes_to_string(self._decorated.get(self._prefix_helper.add_prefix(name)))
+            return self._decorated.get(self._prefix_helper.add_prefix(name))
         except RedisError as exc:
-            raise_from(RedisAdapterException('Error executing get operation'), exc)
+            raise RedisAdapterException('Error executing get operation') from exc
 
     def setex(self, name, time, value):
         """Mimic original redis function but using user custom prefix."""
         try:
             return self._decorated.setex(self._prefix_helper.add_prefix(name), time, value)
         except RedisError as exc:
-            raise_from(RedisAdapterException('Error executing setex operation'), exc)
+            raise RedisAdapterException('Error executing setex operation') from exc
 
     def delete(self, *names):
         """Mimic original redis function but using user custom prefix."""
         try:
             return self._decorated.delete(*self._prefix_helper.add_prefix(list(names)))
         except RedisError as exc:
-            raise_from(RedisAdapterException('Error executing delete operation'), exc)
+            raise RedisAdapterException('Error executing delete operation') from exc
 
     def exists(self, name):
         """Mimic original redis function but using user custom prefix."""
         try:
             return self._decorated.exists(self._prefix_helper.add_prefix(name))
         except RedisError as exc:
-            raise_from(RedisAdapterException('Error executing exists operation'), exc)
+            raise RedisAdapterException('Error executing exists operation') from exc
 
     def lrange(self, key, start, end):
         """Mimic original redis function but using user custom prefix."""
         try:
             return self._decorated.lrange(self._prefix_helper.add_prefix(key), start, end)
         except RedisError as exc:
-            raise_from(RedisAdapterException('Error executing exists operation'), exc)
+            raise RedisAdapterException('Error executing exists operation') from exc
 
     def mget(self, names):
         """Mimic original redis function but using user custom prefix."""
         try:
             return [
-                _bytes_to_string(item)
+                item
                 for item in self._decorated.mget(self._prefix_helper.add_prefix(names))
             ]
         except RedisError as exc:
-            raise_from(RedisAdapterException('Error executing mget operation'), exc)
+            raise RedisAdapterException('Error executing mget operation') from exc
 
     def smembers(self, name):
         """Mimic original redis function but using user custom prefix."""
         try:
             return [
-                _bytes_to_string(item)
+                item
                 for item in self._decorated.smembers(self._prefix_helper.add_prefix(name))
             ]
         except RedisError as exc:
-            raise_from(RedisAdapterException('Error executing smembers operation'), exc)
+            raise RedisAdapterException('Error executing smembers operation') from exc
 
     def sadd(self, name, *values):
         """Mimic original redis function but using user custom prefix."""
         try:
             return self._decorated.sadd(self._prefix_helper.add_prefix(name), *values)
         except RedisError as exc:
-            raise_from(RedisAdapterException('Error executing sadd operation'), exc)
+            raise RedisAdapterException('Error executing sadd operation') from exc
 
     def srem(self, name, *values):
         """Mimic original redis function but using user custom prefix."""
         try:
             return self._decorated.srem(self._prefix_helper.add_prefix(name), *values)
         except RedisError as exc:
-            raise_from(RedisAdapterException('Error executing srem operation'), exc)
+            raise RedisAdapterException('Error executing srem operation') from exc
 
     def sismember(self, name, value):
         """Mimic original redis function but using user custom prefix."""
         try:
             return self._decorated.sismember(self._prefix_helper.add_prefix(name), value)
         except RedisError as exc:
-            raise_from(RedisAdapterException('Error executing sismember operation'), exc)
+            raise RedisAdapterException('Error executing sismember operation') from exc
 
     def eval(self, script, number_of_keys, *keys):
         """Mimic original redis function but using user custom prefix."""
         try:
             return self._decorated.eval(script, number_of_keys, *self._prefix_helper.add_prefix(list(keys)))
         except RedisError as exc:
-            raise_from(RedisAdapterException('Error executing eval operation'), exc)
+            raise RedisAdapterException('Error executing eval operation') from exc
 
     def hset(self, name, key, value):
         """Mimic original redis function but using user custom prefix."""
         try:
             return self._decorated.hset(self._prefix_helper.add_prefix(name), key, value)
         except RedisError as exc:
-            raise_from(RedisAdapterException('Error executing hset operation'), exc)
+            raise RedisAdapterException('Error executing hset operation') from exc
 
     def hget(self, name, key):
         """Mimic original redis function but using user custom prefix."""
         try:
-            return _bytes_to_string(self._decorated.hget(self._prefix_helper.add_prefix(name), key))
+            return self._decorated.hget(self._prefix_helper.add_prefix(name), key)
         except RedisError as exc:
-            raise_from(RedisAdapterException('Error executing hget operation'), exc)
+            raise RedisAdapterException('Error executing hget operation') from exc
 
     def incr(self, name, amount=1):
         """Mimic original redis function but using user custom prefix."""
         try:
             return self._decorated.incr(self._prefix_helper.add_prefix(name), amount)
         except RedisError as exc:
-            raise_from(RedisAdapterException('Error executing incr operation'), exc)
+            raise RedisAdapterException('Error executing incr operation') from exc
 
     def getset(self, name, value):
         """Mimic original redis function but using user custom prefix."""
         try:
-            return _bytes_to_string(self._decorated.getset(self._prefix_helper.add_prefix(name), value))
+            return self._decorated.getset(self._prefix_helper.add_prefix(name), value)
         except RedisError as exc:
-            raise_from(RedisAdapterException('Error executing getset operation'), exc)
+            raise RedisAdapterException('Error executing getset operation') from exc
 
     def rpush(self, key, *values):
         """Mimic original redis function but using user custom prefix."""
         try:
             return self._decorated.rpush(self._prefix_helper.add_prefix(key), *values)
         except RedisError as exc:
-            raise_from(RedisAdapterException('Error executing rpush operation'), exc)
+            raise RedisAdapterException('Error executing rpush operation') from exc
 
     def expire(self, key, value):
         """Mimic original redis function but using user custom prefix."""
         try:
             return self._decorated.expire(self._prefix_helper.add_prefix(key), value)
         except RedisError as exc:
-            raise_from(RedisAdapterException('Error executing expire operation'), exc)
+            raise RedisAdapterException('Error executing expire operation') from exc
 
     def rpop(self, key):
         """Mimic original redis function but using user custom prefix."""
         try:
-            return _bytes_to_string(self._decorated.rpop(self._prefix_helper.add_prefix(key)))
+            return self._decorated.rpop(self._prefix_helper.add_prefix(key))
         except RedisError as exc:
-            raise_from(RedisAdapterException('Error executing rpop operation'), exc)
+            raise RedisAdapterException('Error executing rpop operation') from exc
 
     def ttl(self, key):
         """Mimic original redis function but using user custom prefix."""
         try:
             return self._decorated.ttl(self._prefix_helper.add_prefix(key))
         except RedisError as exc:
-            raise_from(RedisAdapterException('Error executing ttl operation'), exc)
+            raise RedisAdapterException('Error executing ttl operation') from exc
 
     def lpop(self, key):
         """Mimic original redis function but using user custom prefix."""
         try:
             return self._decorated.lpop(self._prefix_helper.add_prefix(key))
         except RedisError as exc:
-            raise_from(RedisAdapterException('Error executing lpop operation'), exc)
+            raise RedisAdapterException('Error executing lpop operation') from exc
 
     def pipeline(self):
         """Mimic original redis pipeline."""
         try:
             return RedisPipelineAdapter(self._decorated, self._prefix_helper)
         except RedisError as exc:
-            raise_from(RedisAdapterException('Error executing ttl operation'), exc)
+            raise RedisAdapterException('Error executing ttl operation') from exc
 
 
 class RedisPipelineAdapter(object):
@@ -345,7 +328,7 @@ class RedisPipelineAdapter(object):
         try:
             return self._pipe.execute()
         except RedisError as exc:
-            raise_from(RedisAdapterException('Error executing pipeline operation'), exc)
+            raise RedisAdapterException('Error executing pipeline operation') from exc
 
 
 def _build_default_client(config):  # pylint: disable=too-many-locals
@@ -370,9 +353,8 @@ def _build_default_client(config):  # pylint: disable=too-many-locals
     unix_socket_path = config.get('redisUnixSocketPath', None)
     encoding = config.get('redisEncoding', 'utf-8')
     encoding_errors = config.get('redisEncodingErrors', 'strict')
-    charset = config.get('redisCharset', None)
     errors = config.get('redisErrors', None)
-    decode_responses = config.get('redisDecodeResponses', False)
+    decode_responses = config.get('redisDecodeResponses', True)
     retry_on_timeout = config.get('redisRetryOnTimeout', False)
     ssl = config.get('redisSsl', False)
     ssl_keyfile = config.get('redisSslKeyfile', None)
@@ -395,7 +377,6 @@ def _build_default_client(config):  # pylint: disable=too-many-locals
         unix_socket_path=unix_socket_path,
         encoding=encoding,
         encoding_errors=encoding_errors,
-        charset=charset,
         errors=errors,
         decode_responses=decode_responses,
         retry_on_timeout=retry_on_timeout,
@@ -449,7 +430,7 @@ def _build_sentinel_client(config):  # pylint: disable=too-many-locals
     connection_pool = config.get('redisConnectionPool', None)
     encoding = config.get('redisEncoding', 'utf-8')
     encoding_errors = config.get('redisEncodingErrors', 'strict')
-    decode_responses = config.get('redisDecodeResponses', False)
+    decode_responses = config.get('redisDecodeResponses', True)
     retry_on_timeout = config.get('redisRetryOnTimeout', False)
     max_connections = config.get('redisMaxConnections', None)
     prefix = config.get('redisPrefix')
